import contextlib
import mysql.connector


@contextlib.contextmanager
def connection(alarmsdb):
    cx = None
    try:
        cx = mysql.connector.connect(
            host=alarmsdb["hostname"],
            user=alarmsdb["username"],
            passwd=alarmsdb["password"],
            db=alarmsdb["dbname"])
        yield cx
    finally:
        if cx:
            cx.close()


@contextlib.contextmanager
def cursor(cnx):
    csr = None
    try:
        csr = cnx.cursor()
        yield csr
    finally:
        if csr:
            csr.close()


def get_last_known_infinera_interface_status(db, equipment, interface):
    query = "SELECT status FROM infinera_alarms" \
            " WHERE" \
            " CONCAT(ne_name, '-', REPLACE(object_name, 'T', '')) = %s" \
            " ORDER BY ne_init_time DESC, ne_clear_time DESC LIMIT 1"
    search_string = equipment + "-" + interface
    with cursor(db) as crs:
        crs.execute(query, (search_string,))
        result = crs.fetchone()
    if not result:
        return "unknown"
    elif result[0] == "Raised":
        return "down"
    else:
        return "up"


def get_last_known_coriant_interface_status(db, equipment, interface):
    query = "SELECT status FROM coriant_alarms" \
            " WHERE ne_id_name = %s AND entity_string LIKE %s" \
            " ORDER BY last_event_time DESC LIMIT 1"
    with cursor(db) as crs:
        crs.execute(query, (equipment, interface + "-%"))
        result = crs.fetchone()
    if not result:
        return "unknown"
    elif result[0] == "Raised":
        return "down"
    else:
        return "up"


def get_last_known_juniper_link_interface_status(db, equipment, interface):
    query = "SELECT IF(link_admin_status = 'up'" \
            " AND link_oper_status = 'up', 1, 0) AS up FROM juniper_alarms" \
            " WHERE equipment_name = %s AND link_interface_name = %s" \
            " ORDER BY alarm_id DESC LIMIT 1"
    with cursor(db) as crs:
        crs.execute(query, ('lo0.' + equipment, interface))
        result = crs.fetchone()
    if not result:
        return "unknown"
    elif result[0] == 0:
        return "down"
    else:
        return "up"


def get_last_known_interface_status(db, equipment, interface):
    result = get_last_known_infinera_interface_status(
        db, equipment, interface)
    if result == "unknown":
        result = get_last_known_coriant_interface_status(
                db, equipment, interface)
    if result == "unknown":
        result = get_last_known_juniper_link_interface_status(
            db, equipment, interface)
    return result
